@@ -1,5 +1,5 @@
 # UMLS::Interface::ICFinder
-# (Last Updated $Id: ICFinder.pm,v 1.18 2010/11/04 22:44:58 btmcinnes Exp $)
+# (Last Updated $Id: ICFinder.pm,v 1.20 2011/03/21 14:06:57 btmcinnes Exp $)
 #
 # Perl module that provides a perl interface to the
 # Unified Medical Language System (UMLS)
@@ -926,10 +926,9 @@ documentation.
 
 =head1 SYNOPSIS
 
- #!/usr/bin/perl
-
  use UMLS::Interface::CuiFinder;
  use UMLS::Interface::ICFinder;
+ use UMLS::Interface::ErrorHandler;
 
  %params = ();
 
